<?php
/**
 * Plugin Name:           GamiPress - WP User Manager integration
 * Plugin URI:            https://wordpress.org/plugins/gamipress-wp-user-manager-integration/
 * Description:           Connect GamiPress with WP User Manager.
 * Version:               1.0.0
 * Author:                GamiPress
 * Author URI:            https://gamipress.com/
 * Text Domain:           gamipress-wp-user-manager-integration
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.2
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               GamiPress\WP_User_Manager
 * @author                GamiPress
 * @copyright             Copyright (c) GamiPress
 */

final class GamiPress_WP_User_Manager {

    /**
     * @var         GamiPress_WP_User_Manager $instance The one true GamiPress_WP_User_Manager
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      GamiPress_WP_User_Manager self::$instance The one true GamiPress_WP_User_Manager
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new GamiPress_WP_User_Manager();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'GAMIPRESS_WP_USER_MANAGER_VER', '1.0.0' );

        // Plugin path
        define( 'GAMIPRESS_WP_USER_MANAGER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'GAMIPRESS_WP_USER_MANAGER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            require_once GAMIPRESS_WP_USER_MANAGER_DIR . 'includes/functions.php';
            require_once GAMIPRESS_WP_USER_MANAGER_DIR . 'includes/listeners.php';
            require_once GAMIPRESS_WP_USER_MANAGER_DIR . 'includes/triggers.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {
        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'GAMIPRESS_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'GamiPress - WP User Manager integration requires %s and %s in order to work. Please install and activate them.', 'gamipress-wp-user-manager-integration' ),
                        '<a href="https://wordpress.org/plugins/gamipress/" target="_blank">GamiPress</a>',
                        '<a href="https://wordpress.org/plugins/wp-user-manager/" target="_blank">WP User Manager</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'GAMIPRESS_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'GamiPress' ) )
            return false;

        // Requirements on multisite install
        if( is_multisite() && gamipress_is_network_wide_active() && is_main_site() ) {
            // On main site, need to check if integrated plugin is installed on any sub site to load all configuration files
            if( gamipress_is_plugin_active_on_network( 'wp-user-manager/wp-user-manager.php' ) )
                return true;
        }

        if ( ! class_exists( 'WP_User_Manager' ) )
            return false;

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = GAMIPRESS_WP_USER_MANAGER_DIR . '/languages/';
        $lang_dir = apply_filters( 'gamipress_wp_user_manager_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gamipress-wp-user-manager-integration' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'gamipress-wp-user-manager-integration', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/gamipress-wp-user-manager-integration/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/gamipress-wp-user-manager-integration/ folder
            load_textdomain( 'gamipress-wp-user-manager-integration', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/gamipress-wp-user-manager-integration/languages/ folder
            load_textdomain( 'gamipress-wp-user-manager-integration', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'gamipress-wp-user-manager-integration', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true GamiPress_WP_User_Manager instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \GamiPress_WP_User_Manager The one true GamiPress_WP_User_Manager
 */
function GamiPress_WP_User_Manager() {
    return GamiPress_WP_User_Manager::instance();
}
add_action( 'plugins_loaded', 'GamiPress_WP_User_Manager' );

